/*
 * Copyright (c) 2022, Shenzhen CVA Innovation CO.,LTD
 * All rights reserved.
 *
 * Shenzhen CVA Innovation CO.,LTD (CVA chip) is supplying this file for use
 * exclusively with CVA's microcontroller products. This file can be freely
 * distributed within development tools that are supporting such microcontroller
 * products.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * CVA SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 */

/*******************************************************************************
 * the includes
 ******************************************************************************/

#include "uds_service11.h"
#include "bootloader.h"

/*******************************************************************************
 * the defines
 ******************************************************************************/

/*******************************************************************************
 * the typedefs
 ******************************************************************************/



/*******************************************************************************
 * the globals
 ******************************************************************************/

/*******************************************************************************
 * the constants
 ******************************************************************************/

/*******************************************************************************
 * the functions
 ******************************************************************************/

void UdsService11_ResetEcu(UdsType *obj, const uint8_t msgBuf[], uint16_t msgLen)
{
    uint8_t subFunction;
    uint8_t rspBuffer[8]  = {0}; /* polyspace DEFECT:PARTIALLY_ACCESSED_ARRAY [No action planned:Low] "Still keep default though member3~7 is not written" */
    uint8_t powerDownTime = 0xFF;

    if(msgLen != obj->seviceTable[obj->curServiceIdx].minLen)
    {
        Uds_NegativeResponse(obj, 0x11, NRC_INVALID_MESSAGE_LENGTH_OR_FORMAT);
        return;
    }

    subFunction = UDS_GET_SUB_FUNCTION(msgBuf[1]);

    rspBuffer[0] = UDS_GET_POSITIVE_RSP(0x11);
    rspBuffer[1] = subFunction;
    rspBuffer[2] = powerDownTime;
    switch(subFunction)
    {
    case UDS_RESET_HARD:
        Uds_PositiveResponse(obj, rspBuffer, 3);
        /*add hardware reset code*/
        Bootloader_EventResetRequest(true,UDS_RESET_HARD);
        break;
    case UDS_RESET_KEYOFFON:
        Uds_PositiveResponse(obj, rspBuffer, 3);
        /*add keyoffon reset code*/
        Bootloader_EventResetRequest(true,UDS_RESET_KEYOFFON);
        break;
    case UDS_RESET_SOFT:
        Uds_PositiveResponse(obj, rspBuffer, 3);
        /*add software reset code*/
        Bootloader_EventResetRequest(true,UDS_RESET_SOFT);
        break;
    default:
        Uds_NegativeResponse(obj, 0x11, NRC_SUBFUNCTION_NOT_SUPPORTED);
        break;
    }
}
